==> dee_1.0.10.orig.tar.gz: dee-1.0.10/src/dee-marshal.h <==

#ifndef ___dee_marshal_MARSHAL_H__
#define ___dee_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOXED,BOXED,BOXED (./dee-marshal.list:2) */
extern void _dee_marshal_VOID__BOXED_BOXED_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:BOXED,BOXED (./dee-marshal.list:5) */
extern void _dee_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:UINT64,UINT64 (./dee-marshal.list:8) */
extern void _dee_marshal_VOID__UINT64_UINT64 (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:STRING,STRING (./dee-marshal.list:11) */
extern void _dee_marshal_VOID__STRING_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

G_END_DECLS

#endif /* ___dee_marshal_MARSHAL_H__ */

==> dee_1.0.14.orig.tar.gz: dee-1.0.14/src/dee-marshal.h <==

#ifndef ___dee_marshal_MARSHAL_H__
#define ___dee_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:BOXED,BOXED,BOXED (../../src/dee-marshal.list:2) */
extern void _dee_marshal_VOID__BOXED_BOXED_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
                                                  const GValue *param_values,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);

/* VOID:BOXED,BOXED (../../src/dee-marshal.list:5) */
extern void _dee_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:UINT64,UINT64 (../../src/dee-marshal.list:8) */
extern void _dee_marshal_VOID__UINT64_UINT64 (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:STRING,STRING (../../src/dee-marshal.list:11) */
extern void _dee_marshal_VOID__STRING_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

G_END_DECLS

#endif /* ___dee_marshal_MARSHAL_H__ */
